"""
The MIT License (MIT)

Copyright (c) 2015 Zachary Seguin

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

# Based on: http://hints.macworld.com/article.php?story=20011108211802830

from manager import Manager
import os
import terminal

manager = Manager()

def do(action):
   import subprocess
   return subprocess.check_output('osascript -e \'tell application "iTunes" to {action}\''.format(action=action), shell=True).replace('\n', '');

@manager.command
def status():
   "Get iTunes status."

   import datetime

   status = do('player state as string')

   if status == 'playing':
      song = do('name of current track as string')
      artist = do('artist of current track as string')
      album = do('album of current track as string')
      year = do('year of current track as string')
      genre = do('genre of current track as string')
      length = do('duration of current track as string')

      print(terminal.blue('     Song: ') + song)
      print(terminal.blue('   Artist: ') + artist)
      print(terminal.blue('    Album: ') + album)
      print(terminal.blue('     Year: ') + year)
      print(terminal.blue('    Genre: ') + genre)
      print(terminal.blue('   Length: ') + str(datetime.timedelta(seconds=float(length))))
      return None

   return 'iTunes is not currently playing any music.'

@manager.command
def play():
   "Play iTunes music."
   do('play')
   return status()

@manager.command
def pause():
   "Pause iTunes music."
   do('pause')

@manager.command
def stop():
   "Stop iTunes music."
   do('stop')

@manager.command
def next():
   "Move to the next iTunes track."
   do('next track')
   return status()

@manager.command
def previous():
   "Move to the previous iTunes track."
   do('previous track')
   return status()

@manager.command
def mute():
   "Mute iTunes."
   do('set mute to true')

@manager.command
def unmute():
   "Unmute iTunes."
   do('set mute to false')

@manager.command
def volume(value):
   "Change the volume"
   vol = int(do('sound volume as integer'))

   if value == 'up':
      vol += 10
   elif value == 'down':
      vol -= 10
   else:
      vol = value

   do('set sound volume to {vol}'.format(vol=vol))
